@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-from optparse import OptionParser
 import os, stat
 import sys
 import logging
