@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 import logging
@@ -8,6 +7,8 @@ import subprocess
 from lxml import etree
 from pytrainer.lib.date import getDateTime
 from pytrainer.lib.xmlUtils import XMLParser
+from pytrainer.core.activity import Activity
+from sqlalchemy.orm import exc
 
 class garminfit():
     '''First approach to parse Garmin FIT files is to use perl scripts (http://pub.ks-and-ks.ne.jp/cycling/fit2tcx.shtml) from Kiyokazu SUTO (suto@ks-and-ks.ne.jp) to convert first to TCXv2 and then to GPX+ format.
@@ -16,11 +17,11 @@ class garminfit():
     def __init__(self, parent = None, data_path = None):
         self.parent = parent
         if parent is not None:
-        	self.pytrainer_main = parent.parent
-        	self.tmpdir = self.pytrainer_main.profile.tmpdir
+            self.pytrainer_main = parent.parent
+            self.tmpdir = self.pytrainer_main.profile.tmpdir
         if data_path is not None:
-        	self.main_data_path = data_path
-        	self.data_path = os.path.dirname(__file__)
+            self.main_data_path = data_path
+            self.data_path = os.path.dirname(__file__)
         self.xmldoc = None
         self.activitiesSummary = []
         self.activities = []
@@ -50,7 +51,7 @@ class garminfit():
                 hours = int(duration)//3600
                 minutes = (int(duration)/60)%60
                 seconds = int(duration)%60
-                duration_hhmmss = "%02d:%02d:%02d" % (hours, minutes, seconds)       
+                duration_hhmmss = "%02d:%02d:%02d" % (hours, minutes, seconds)
             logging.debug("Activity distance (m): %f | duration (hh:mm:ss - s): %s - %f" % (distance, duration_hhmmss, duration))
         else:
             points = activity.findall(".//{http://www.garmin.com/xmlschemas/TrainingCenterDatabase/v2}Trackpoint")
@@ -79,10 +80,11 @@ class garminfit():
         logging.debug(">>")
         result = False
         try:
-            pipe = subprocess.Popen(["perl", self.main_data_path+"plugins/garmin-fit/bin/fit2tcx", filename], stdout=subprocess.PIPE)
-            result = pipe.stdout.read()
-        except:
-            logging.debug("Traceback: %s" % traceback.format_exc())
+            result = subprocess.check_output(["perl",
+                                              self.main_data_path+"plugins/garmin-fit/bin/fit2tcx",
+                                              filename])
+        except subprocess.CalledProcessError:
+            logging.exception("fit2tcx failed")
         logging.debug("<<")
         return result
 
@@ -100,10 +102,10 @@ class garminfit():
             distance, duration  = self.getDetails(activity, startTime)
             distance = distance / 1000.0
             self.activitiesSummary.append((self.activities.index(activity),
-                                                                 inDatabase, 
-                                                                 startTime[1].strftime("%Y-%m-%dT%H:%M:%S"), 
-                                                                 "%0.2f" % distance , 
-                                                                 str(duration), 
+                                                                 inDatabase,
+                                                                 startTime[1].strftime("%Y-%m-%dT%H:%M:%S"),
+                                                                 "%0.2f" % distance ,
+                                                                 str(duration),
                                                                  sport,
                                                                  ))
 
@@ -121,7 +123,7 @@ class garminfit():
                 return True
         except:
             logging.debug("Traceback: %s" % traceback.format_exc())
-            return False 
+            return False
         return False
 
     def getActivities(self):
@@ -137,8 +139,11 @@ class garminfit():
         if startTime is not None:
             logging.info("Checking if activity from %s exists in db" % startTime[0])
             time = startTime[0].strftime("%Y-%m-%dT%H:%M:%SZ")
-            if self.parent.parent.ddbb.select("records","*","date_time_utc=\"%s\"" % (time)):
+            try:
+                self.parent.parent.ddbb.session.query(Activity).filter(Activity.date_time_utc == time).one()
                 result = True
+            except exc.NoResultFound:
+                pass
         else:
             logging.info("No start time provided, nothing to check")
         logging.debug('<<')
@@ -146,7 +151,7 @@ class garminfit():
 
     def getSport(self, activity):
         try:
-            sport = activity.get("Sport")
+            sport = activity.get("Sport").decode("utf-8")
         except:
             sport = "import"
         return sport
@@ -173,7 +178,7 @@ class garminfit():
             activity = self.activities[int(activityID)]
             sport = self.getSport(activity)
             self.createGPXfile(gpxFile, activity)
-        return sport, gpxFile  
+        return sport, gpxFile
 
     def createGPXfile(self, gpxfile, activity):
         """ Function to transform a Garmin Training Center v2 Track to a valid GPX+ file
@@ -183,4 +188,3 @@ class garminfit():
         xml_doc = activity
         result_tree = transform(xml_doc)
         result_tree.write(gpxfile, xml_declaration=True, encoding='UTF-8')
-
