@@ -1,4 +1,4 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 
 #Copyright (C) Fiz Vazquez vud1@sindominio.net
 
@@ -492,7 +492,7 @@ tracks (%s)
             logging.debug("Time: %f, Dist: %f, Pace: %f, Speed: %f", time, dist, pace, avg_speed)
             self._lap_time.addBars(x=time, y=10)
             self._lap_distance.addBars(x=self.uc.distance(dist), y=10)
-            self.distance_data['pace_lap'].addBars(x=self.uc.distance(dist), y=pacekm2miles(pace))
+            self.distance_data['pace_lap'].addBars(x=self.uc.distance(dist), y=self.uc.distance(pace))
             self.time_data['pace_lap'].addBars(x=time, y=self.uc.speed(pace))
             self.distance_data['speed_lap'].addBars(x=self.uc.distance(dist), y=self.uc.speed(avg_speed))
             self.time_data['speed_lap'].addBars(x=time, y=self.uc.speed(avg_speed))
