@@ -1,4 +1,4 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 
 #Copyright (C) Fiz Vazquez vud1@sindominio.net
 
@@ -18,12 +18,16 @@
 
 import os
 import re
-import html
 import logging
 import colorsys
 import math
 import traceback
 
+try:
+    import html
+except ImportError:
+    import cgi as html
+
 import pytrainer.lib.points as Points
 from pytrainer.lib.fileUtils import fileUtils
 from pytrainer.lib.uc import UC
