@@ -1,4 +1,4 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 
 #Copyright (C) Fiz Vazquez vud1@sindominio.net
 
@@ -16,14 +16,22 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+import logging
+
 class fileUtils:
-	def __init__(self, filename, data):
-		self.filename = filename
-		self.data = data
+    def __init__(self, filename, data):
+        self.filename = filename
+        self.data = data
 
-	def run(self):
-        	out = open(self.filename, 'w')
-		out.write(self.data)
-            	out.close()
+    def run(self):
+        logging.debug('>>')
+        if self.data is not None:
+            logging.debug("Writing in %s " % self.filename) 
+            out = open(self.filename, 'w')
+            out.write(self.data)
+            out.close()
+        else:
+            logging.error("Nothing to write in %s" % self.filename)
+        logging.debug('<<')
 
 
