@@ -1,10 +1,16 @@
 # -*- coding: utf-8 -*-
 from unittest import TestCase
-from mock import Mock
+try:
+    from unittest.mock import Mock
+except ImportError:
+    from mock import Mock
 from pytrainer.core.equipment import Equipment, EquipmentService
-from pytrainer.gui.equipment import EquipmentStore
+from pytrainer.gui.equipment import EquipmentStore, EquipmentUi
+from pytrainer.lib.ddbb import DDBB
+from pytrainer.lib.localization import initialize_gettext
 
 #Copyright (C) Nathan Jones ncjones@users.sourceforge.net
+#Copyright (C) Arto Jantunen <viiru@iki.fi>
 
 #This program is free software; you can redistribute it and/or
 #modify it under the terms of the GNU General Public License
@@ -35,7 +41,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_all_equipment.return_value = [equipment]
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals(1, equipment_store.get_value(iter, 0))
+        self.assertEqual(1, equipment_store.get_value(iter, 0))
         
     def test_get_item_description(self):
         equipment = Equipment()
@@ -44,7 +50,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_all_equipment.return_value = [equipment]
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals("item description", equipment_store.get_value(iter, 1))
+        self.assertEqual("item description", equipment_store.get_value(iter, 1))
         
     def test_get_item_usage_percent(self):
         equipment = Equipment()
@@ -54,7 +60,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 100
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals(50, equipment_store.get_value(iter, 2))
+        self.assertEqual(50, equipment_store.get_value(iter, 2))
         
     def test_get_item_usage_percent_prior_usage(self):
         equipment = Equipment()
@@ -65,7 +71,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 100
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals(75, equipment_store.get_value(iter, 2))
+        self.assertEqual(75, equipment_store.get_value(iter, 2))
         
     def test_get_item_usage_percent_zero_usage(self):
         equipment = Equipment()
@@ -75,7 +81,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 0
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals(0, equipment_store.get_value(iter, 2))
+        self.assertEqual(0, equipment_store.get_value(iter, 2))
         
     def test_get_item_usage_percent_usage_exceeds_life_expectancy(self):
         equipment = Equipment()
@@ -85,7 +91,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 300
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals(100, equipment_store.get_value(iter, 2), "Progress bar cannot exceed 100%.")
+        self.assertEqual(100, equipment_store.get_value(iter, 2), "Progress bar cannot exceed 100%.")
         
         
     def test_get_item_usage_text(self):
@@ -96,17 +102,17 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 100
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals("100 / 200", equipment_store.get_value(iter, 3))
+        self.assertEqual("100 / 200", equipment_store.get_value(iter, 3))
         
     def test_get_item_usage_text_rounded(self):
         equipment = Equipment()
         equipment.id = 1
         equipment.life_expectancy = 200
         self.mock_equipment_service.get_all_equipment.return_value = [equipment]
-        self.mock_equipment_service.get_equipment_usage.return_value = 100.5
+        self.mock_equipment_service.get_equipment_usage.return_value = 100.6
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals("101 / 200", equipment_store.get_value(iter, 3))
+        self.assertEqual("101 / 200", equipment_store.get_value(iter, 3))
         
     def test_get_item_usage_text_prior_usage(self):
         equipment = Equipment()
@@ -117,7 +123,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 100
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals("150 / 200", equipment_store.get_value(iter, 3))
+        self.assertEqual("150 / 200", equipment_store.get_value(iter, 3))
         
     def test_get_item_usage_text_zero_usage(self):
         equipment = Equipment()
@@ -127,7 +133,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 0
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals("0 / 200", equipment_store.get_value(iter, 3))
+        self.assertEqual("0 / 200", equipment_store.get_value(iter, 3))
         
     def test_get_item_usage_text_usage_exceeds_life_expectancy(self):
         equipment = Equipment()
@@ -137,7 +143,7 @@ class EquipmentStoreTest(TestCase):
         self.mock_equipment_service.get_equipment_usage.return_value = 300
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
-        self.assertEquals("300 / 200", equipment_store.get_value(iter, 3))
+        self.assertEqual("300 / 200", equipment_store.get_value(iter, 3))
         
     def test_get_item_active(self):
         equipment = Equipment()
@@ -157,6 +163,39 @@ class EquipmentStoreTest(TestCase):
         equipment_store = EquipmentStore(self.mock_equipment_service)
         iter = equipment_store.get_iter_first()
         iter = equipment_store.iter_next(iter)
-        self.assertEquals(2, equipment_store.get_value(iter, 0))
+        self.assertEqual(2, equipment_store.get_value(iter, 0))
         
+class EquipmentUiTest(TestCase):
 
+    def setUp(self):
+        initialize_gettext('locale/')
+        self.ddbb = DDBB()
+        self.ddbb.connect()
+        self.ddbb.create_tables()
+        self.equipment_service = EquipmentService(self.ddbb)
+        self.equipment_ui = EquipmentUi('glade/', self.equipment_service)
+
+    def tearDown(self):
+        self.ddbb.disconnect()
+        self.ddbb.drop_tables()
+
+    def test_equipment_add(self):
+        self.equipment_ui._builder.get_object("entryEquipmentAddDescription").set_text('Test')
+        self.equipment_ui._builder.get_object("entryEquipmentAddLifeExpectancy").set_text('500')
+        self.equipment_ui._builder.get_object("entryEquipmentAddPriorUsage").set_text('100')
+        self.equipment_ui._builder.get_object("checkbuttonEquipmentAddActive").set_active(is_active=True)
+        self.equipment_ui._confirm_add_equipment_clicked(None)
+        equipment = self.equipment_service.get_equipment_item(1)
+        self.assertEqual(equipment.description, 'Test')
+        self.assertEqual(equipment.life_expectancy, 500)
+        self.assertEqual(equipment.prior_usage, 100)
+        self.assertTrue(equipment.active)
+
+    def test_equipment_add_unicode(self):
+        self.equipment_ui._builder.get_object("entryEquipmentAddDescription").set_text(u'Test äö')
+        self.equipment_ui._builder.get_object("entryEquipmentAddLifeExpectancy").set_text('500')
+        self.equipment_ui._builder.get_object("entryEquipmentAddPriorUsage").set_text('100')
+        self.equipment_ui._builder.get_object("checkbuttonEquipmentAddActive").set_active(is_active=True)
+        self.equipment_ui._confirm_add_equipment_clicked(None)
+        equipment = self.equipment_service.get_equipment_item(1)
+        self.assertEqual(equipment.description, u'Test äö')
