@@ -16,11 +16,10 @@
 
 import unittest
 from datetime import date
-from mock import Mock
-
-# Gettext needs to be initialized before UC is imported (via profile)
-import pytrainer.lib.localization
-pytrainer.lib.localization.initialize_gettext("../../locale")
+try:
+    from unittest.mock import Mock
+except ImportError:
+    from mock import Mock
 
 from pytrainer.lib.ddbb import DDBB
 from pytrainer.profile import Profile
@@ -29,9 +28,7 @@ from pytrainer.athlete import Athlete
 class AthleteTest(unittest.TestCase):
 
     def setUp(self):
-        profile = Mock()
-        profile.getValue = Mock(return_value='memory')
-        self.ddbb = DDBB(profile)
+        self.ddbb = DDBB()
         main = Mock()
         main.ddbb = self.ddbb
         main.profile = Profile()
@@ -42,7 +39,7 @@ class AthleteTest(unittest.TestCase):
     def tearDown(self):
         self.athlete = None
         self.ddbb.disconnect()
-        self.ddbb = None
+        self.ddbb.drop_tables()
 
     def test_athlete_insert_and_get(self):
         data = {'date': date(2017, 4, 3), 'weight': 60.0, 'bodyfat': 20.0,
@@ -51,7 +48,7 @@ class AthleteTest(unittest.TestCase):
                                           data['bodyfat'], data['restinghr'],
                                           data['maxhr'])
         data2 = self.athlete.get_athlete_stats()
-        self.assertEquals(data, data2[0])
+        self.assertEqual(data, data2[0])
 
     def test_athlete_update_and_get(self):
         data = {'date': date(2017, 4, 3), 'weight': 60.0, 'bodyfat': 20.0,
@@ -65,7 +62,7 @@ class AthleteTest(unittest.TestCase):
                                           data['bodyfat'], data['restinghr'],
                                           data['maxhr'])
         data2 = self.athlete.get_athlete_stats()
-        self.assertEquals(data, data2[0])
+        self.assertEqual(data, data2[0])
 
     def test_athlete_delete_record(self):
         data = {'date': date(2017, 4, 3), 'weight': 60.0, 'bodyfat': 20.0,
